@@ -1,7 +1,6 @@
 #[cfg(feature = "build-binary")]
 pub mod console;
-mod editorconfig_lexer;
-mod editorconfig_parser;
+mod editorconfig;
 mod enumerable;
 pub mod glob;
 pub mod similar;
@@ -17,10 +16,6 @@ extern crate aho_corasick;
 extern crate jwalk;
 extern crate nom;
 
-#[cfg(test)] // <-- not needed in integration tests
-#[macro_use]
-extern crate spectral;
-
 #[cfg(test)] // <-- not needed in integration tests
 #[macro_use]
 extern crate table_test;
@@ -28,7 +23,7 @@ extern crate table_test;
 #[cfg(test)] // <-- not needed in integration tests
 extern crate rstest;
 
-use crate::editorconfig_parser::Section;
+use editorconfig::Section;
 use jwalk::{Parallelism, WalkDir};
 use std::collections::{BTreeMap, BTreeSet, HashMap};
 
@@ -78,9 +73,9 @@ pub struct ExtValidationResult<'input> {
     pub similar: Vec<(&'input str, &'input str)>,
 }
 
-pub struct Property<'input> {
+/// Property with section that contain it
+struct ExtendedProperty<'input> {
     pub name: &'input str,
-    pub value: &'input str,
     pub section: &'input str,
 }
 
@@ -134,7 +129,9 @@ pub fn validate_all<V: ValidationFormatter, E: Errorer>(
 ) -> usize {
     let parallelism = Parallelism::RayonNewPool(num_cpus::get_physical());
 
-    let iter = WalkDir::new(path)
+    let root = decorate_path(path);
+
+    let iter = WalkDir::new(root)
         .skip_hidden(false)
         .follow_links(false)
         .parallelism(parallelism);
@@ -204,15 +201,22 @@ pub fn validate<V: ValidationFormatter>(content: &str, path: &str, formatter: &V
     let mut sim_props = BTreeMap::new();
     let mut all_ext_props = BTreeMap::new();
 
-    let sections = editorconfig_parser::parse(content);
+    let sections = editorconfig::parse(content);
     let mut section_heads = Vec::new();
 
     for sec in &sections {
-        for e in &sec.extensions {
+        let extensions = glob::parse(sec.title);
+        let props_fn = || {
+            sec.properties.iter().map(|x| ExtendedProperty {
+                name: x.name,
+                section: sec.title,
+            })
+        };
+        for e in extensions {
             all_ext_props
                 .entry(e)
                 .or_insert_with(Vec::new)
-                .extend(&sec.properties);
+                .extend(props_fn());
         }
         section_heads.push(sec.title);
 
@@ -230,7 +234,7 @@ pub fn validate<V: ValidationFormatter>(content: &str, path: &str, formatter: &V
 
     let ext_problems: Vec<ExtValidationResult> = all_ext_props
         .into_iter()
-        .map(|(ext, props)| validate_extension(ext.to_string(), props))
+        .map(|(ext, props)| validate_extension(ext, props))
         .filter(|r| !r.duplicates.is_empty() || !r.similar.is_empty())
         .collect();
 
@@ -253,7 +257,7 @@ fn append_to_btree<'a, T>(bree: &mut BTreeMap<&'a str, Vec<T>>, key: &'a str, da
     }
 }
 
-fn validate_extension<'a>(ext: String, props: Vec<&'a Property>) -> ExtValidationResult<'a> {
+fn validate_extension(ext: String, props: Vec<ExtendedProperty>) -> ExtValidationResult {
     let props_sections = props.into_iter().map(|p| (p.name, p.section)).fold(
         HashMap::new(),
         |mut h, (prop, sect)| {
@@ -289,8 +293,8 @@ fn validate_extension<'a>(ext: String, props: Vec<&'a Property>) -> ExtValidatio
 pub fn compare<F: ComparisonFormatter>(content1: &str, content2: &str, formatter: &F) {
     let empty = BTreeMap::<&str, &str>::new();
 
-    let f1 = editorconfig_parser::parse(content1);
-    let f2 = editorconfig_parser::parse(content2);
+    let f1 = editorconfig::parse(content1);
+    let f2 = editorconfig::parse(content2);
 
     let s1_props = map_sections(&f1);
     let s2_props = map_sections(&f2);
@@ -349,11 +353,26 @@ fn map_sections<'a>(sections: &'a [Section<'a>]) -> HashMap<&'a str, BTreeMap<&'
         .collect()
 }
 
+/// On Windows added trailing back slash \ if volume and colon passed so as to paths look more pleasant
+#[cfg(target_os = "windows")]
+fn decorate_path(path: &str) -> String {
+    if path.len() == 2 && path.ends_with(':') {
+        format!("{}\\", path)
+    } else {
+        String::from(path)
+    }
+}
+
+/// On Unix just passthrough as is
+#[cfg(not(target_os = "windows"))]
+fn decorate_path(path: &str) -> String {
+    String::from(path)
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
     use rstest::*;
-    use spectral::prelude::*;
 
     struct TestFormatter<F>
     where
@@ -417,8 +436,8 @@ c = d
 [*.md]
 e = f"###;
         let formatter = TestFormatter::new(|result: ValidationResult| {
-            assert_that!(result.is_ok()).is_true();
-            assert_that(&result.state()).is_equal_to(ValidationState::Valid);
+            assert!(result.is_ok());
+            assert_eq!(result.state(), ValidationState::Valid);
         });
 
         // Act
@@ -435,8 +454,8 @@ e = f"###;
     fn validate_arbitrary(#[case] content: &str, #[case] path: &str, #[case] expected: bool) {
         // Arrange
         let formatter = TestFormatter::new(|result: ValidationResult| {
-            assert_that!(result.is_ok()).is_equal_to(expected);
-            assert_that(&result.state()).is_equal_to(ValidationState::SomeProblems);
+            assert_eq!(result.is_ok(), expected);
+            assert_eq!(result.state(), ValidationState::SomeProblems);
         });
 
         // Act
@@ -452,7 +471,7 @@ e = f"###;
         // Arrange
 
         // Act
-        assert_that!(state.is_ok()).is_equal_to(expected);
+        assert_eq!(state.is_ok(), expected);
     }
 
     #[test]
@@ -464,8 +483,8 @@ a = b
 c = d
 "###;
         let formatter = TestFormatter::new(|result: ValidationResult| {
-            assert_that!(result.is_ok()).is_true();
-            assert_that(&result.state()).is_equal_to(ValidationState::Valid);
+            assert!(result.is_ok());
+            assert_eq!(result.state(), ValidationState::Valid);
         });
 
         // Act
@@ -481,8 +500,8 @@ a = b # comment 1
 c = d # comment 2
 "###;
         let formatter = TestFormatter::new(|result: ValidationResult| {
-            assert_that!(result.is_ok()).is_true();
-            assert_that(&result.state()).is_equal_to(ValidationState::Valid);
+            assert!(result.is_ok());
+            assert_eq!(result.state(), ValidationState::Valid);
         });
 
         // Act
@@ -502,10 +521,10 @@ c = d
 [*.md]
 e = f"###;
         let formatter = TestFormatter::new(|result: ValidationResult| {
-            assert_that(&result.duplicate_properties.is_empty()).is_false();
-            assert_that(&result.duplicate_sections.is_empty()).is_true();
-            assert_that(&result.similar_properties.is_empty()).is_true();
-            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
+            assert!(!result.duplicate_properties.is_empty());
+            assert!(result.duplicate_sections.is_empty());
+            assert!(result.similar_properties.is_empty());
+            assert_eq!(result.state(), ValidationState::Invalid);
         });
 
         // Act
@@ -528,8 +547,8 @@ e = f"###;
             assert!(result.duplicate_properties.is_empty());
             assert!(result.duplicate_sections.is_empty());
             assert!(!result.similar_properties.is_empty());
-            assert_that!(result.ext_problems).is_empty();
-            assert_that(&result.state()).is_equal_to(ValidationState::SomeProblems);
+            assert!(result.ext_problems.is_empty());
+            assert_eq!(result.state(), ValidationState::SomeProblems);
         });
 
         // Act
@@ -553,8 +572,8 @@ e = f"###;
             assert!(!result.duplicate_properties.is_empty());
             assert!(result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
-            assert_that!(result.ext_problems).is_empty();
-            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
+            assert!(result.ext_problems.is_empty());
+            assert_eq!(result.state(), ValidationState::Invalid);
         });
 
         // Act
@@ -576,8 +595,8 @@ a = d
             assert!(result.duplicate_properties.is_empty());
             assert!(result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
-            assert_that!(result.ext_problems).has_length(1);
-            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
+            assert_eq!(result.ext_problems.len(), 1);
+            assert_eq!(result.state(), ValidationState::Invalid);
         });
 
         // Act
@@ -599,8 +618,8 @@ d_a_b_c = d
             assert!(result.duplicate_properties.is_empty());
             assert!(result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
-            assert_that!(result.ext_problems).has_length(1);
-            assert_that(&result.state()).is_equal_to(ValidationState::SomeProblems);
+            assert_eq!(result.ext_problems.len(), 1);
+            assert_eq!(result.state(), ValidationState::SomeProblems);
         });
 
         // Act
@@ -623,7 +642,7 @@ e = f"###;
             assert!(result.duplicate_properties.is_empty());
             assert!(!result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
-            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
+            assert_eq!(result.state(), ValidationState::Invalid);
         });
 
         // Act
@@ -646,7 +665,7 @@ c = d2
 
         let formatter = TestCompareFormatter::new(|res: BTreeMap<&str, Vec<CompareItem>>| {
             assert_eq!(1, res.len());
-            assert_that(res.get("*").unwrap()).has_length(2);
+            assert_eq!(res.get("*").unwrap().len(), 2);
         });
 
         // Act
@@ -673,10 +692,10 @@ c = d2
 
         let formatter = TestCompareFormatter::new(|res: BTreeMap<&str, Vec<CompareItem>>| {
             assert_eq!(2, res.len());
-            assert_that!(res.get("*")).is_some();
-            assert_that(res.get("*").unwrap()).has_length(2);
-            assert_that!(res.get("")).is_some();
-            assert_that(res.get("").unwrap()).has_length(1);
+            assert!(res.get("*").is_some());
+            assert_eq!(res.get("*").unwrap().len(), 2);
+            assert!(res.get("").is_some());
+            assert_eq!(res.get("").unwrap().len(), 1);
         });
 
         // Act
@@ -698,7 +717,7 @@ d = d2
 "###;
         let formatter = TestCompareFormatter::new(|res: BTreeMap<&str, Vec<CompareItem>>| {
             assert_eq!(1, res.len());
-            assert_that(res.get("*").unwrap()).has_length(3);
+            assert_eq!(res.get("*").unwrap().len(), 3);
         });
 
         // Act
@@ -720,11 +739,45 @@ d = d2
 "###;
         let formatter = TestCompareFormatter::new(|res: BTreeMap<&str, Vec<CompareItem>>| {
             assert_eq!(2, res.len());
-            assert_that(res.get("x").unwrap()).has_length(2);
-            assert_that(res.get("y").unwrap()).has_length(2);
+            assert_eq!(res.get("x").unwrap().len(), 2);
+            assert_eq!(res.get("y").unwrap().len(), 2);
         });
 
         // Act
         compare(config1, config2, &formatter);
     }
+
+    #[cfg(not(target_os = "windows"))]
+    #[rstest]
+    #[case("", "")]
+    #[case("/", "/")]
+    #[case("/home", "/home")]
+    #[case("d:", "d:")]
+    #[trace]
+    fn decorate_path_tests(#[case] raw_path: &str, #[case] expected: &str) {
+        // Arrange
+
+        // Act
+        let actual = decorate_path(raw_path);
+
+        // Assert
+        assert_eq!(actual, expected);
+    }
+
+    #[cfg(target_os = "windows")]
+    #[rstest]
+    #[case("", "")]
+    #[case("/", "/")]
+    #[case("d:", "d:\\")]
+    #[case("dd:", "dd:")]
+    #[trace]
+    fn decorate_path_tests(#[case] raw_path: &str, #[case] expected: &str) {
+        // Arrange
+
+        // Act
+        let actual = decorate_path(raw_path);
+
+        // Assert
+        assert_eq!(actual, expected);
+    }
 }
